<?php

require_once "Assets/fpdf/fpdf.php";

//create new class extending fpdf class
class PDF extends FPDF {
	// variable to store widths and aligns of cells, and line height
	var $widths;
	var $aligns;
	var $lineHeight;

	//Set the array of column widths
	function SetWidths($w){
		$this->widths=$w;
	}

	//Set the array of column alignments
	function SetAligns($a){
		$this->aligns=$a;
	}

	//Set line height
	function SetLineHeight($h){
		$this->lineHeight=$h;
	}

	//Calculate the height of the row
	function Row($data)
	{
		// number of line
		$nb=0;
		
		// loop each data to find out greatest line number in a row.
		for($i=0;$i<count($data);$i++){
			// NbLines will calculate how many lines needed to display text wrapped in specified width.
			// then max function will compare the result with current $nb. Returning the greatest one. And reassign the $nb.
			$nb=max($nb,$this->NbLines($this->widths[$i],$data[$i]));
		}
		
		//multiply number of line with line height. This will be the height of current row
		$h=$this->lineHeight * $nb;
		
		//Issue a page break first if needed
		$this->CheckPageBreak($h);
		
		//Draw the cells of current row
		for($i=0;$i<count($data);$i++)
		{
			// width of the current col
			$w=$this->widths[$i];
			
			// alignment of the current col. if unset, make it left.
			$a=isset($this->aligns[$i]) ? $this->aligns[$i] : 'L';
			
			//Save the current position
			$x=$this->GetX();
			$y=$this->GetY();
			
			//Draw the border
			$this->Rect($x,$y,$w,$h);
			
			//Print the text
			$this->MultiCell($w,5,$data[$i],0,$a);
			
			//Put the position to the right of the cell
			$this->SetXY($x+$w,$y);
		}
		//Go to the next line
		$this->Ln($h);
	}

	function CheckPageBreak($h)
	{
		//If the height h would cause an overflow, add a new page immediately
		if($this->GetY()+$h>$this->PageBreakTrigger)
			$this->AddPage($this->CurOrientation);
	}

	function NbLines($w,$txt)
	{
		//calculate the number of lines a MultiCell of width w will take
		$cw=&$this->CurrentFont['cw'];
		if($w==0)
			$w=$this->w-$this->rMargin-$this->x;
		$wmax=($w-2*$this->cMargin)*1000/$this->FontSize;
		$s=str_replace("\r",'',$txt);
		$nb=strlen($s);
		if($nb>0 and $s[$nb-1]=="\n")
			$nb--;
		$sep=-1;
		$i=0;
		$j=0;
		$l=0;
		$nl=1;
		while($i<$nb)
		{
			$c=$s[$i];
			if($c=="\n")
			{
				$i++;
				$sep=-1;
				$j=$i;
				$l=0;
				$nl++;
				continue;
			}
			if($c==' ')
				$sep=$i;
			$l+=$cw[$c];
			if($l>$wmax)
			{
				if($sep==-1)
				{
					if($i==$j)
						$i++;
				}
				else
					$i=$sep+1;
				$sep=-1;
				$j=$i;
				$l=0;
				$nl++;
			}
			else
				$i++;
		}
		return $nl;
	}
}
	
//make new object
$pdf = new PDF('P');
setlocale(LC_ALL,"es_ES");
//add page, set font
$pdf->AddPage();

$pdf->SetMargins(30,15,20);
$pdf->Image('Assets/img/fondo_agua.jpg',60,90,100,100);	
$pdf->Ln(30);
$pdf->SetFont('Arial','',12);
$pdf->Cell(100,2,utf8_decode("El Presidente del Comité de Educación de la Cooperativa Crl Francisco Bolognesi, "),0,0);
$pdf->Ln(5);
$pdf->Cell(100,2,"Certifica que:",0,0);
$pdf->Ln(5);
$pdf->SetFont('Arial','B',12);
$pdf->Cell(100,2, utf8_decode($data['alumno']['alumno']),0,0);		
$pdf->Ln(5);
$pdf->SetFont('Arial','',12);
$pdf->Cell(100,2,utf8_decode("ha concluido satisfactoriamente el Curso de: ".$data['alumno']['curso']." del"),0,0);
$pdf->Ln(5);
$pdf->Cell(100,2,utf8_decode("Aula Virtual."),0,0);
$pdf->Ln(5);
$pdf->Cell(100,2,utf8_decode("Habiendo obtenido los calificativos siguientes:"),0,0);
$pdf->Ln(10);

//set width for each column (6 columns)
$pdf->SetWidths(Array(50,80,25));
$pdf->SetAligns(array('L','L','C'));

//set alignment
//$pdf->SetAligns(Array('','R','C','','',''));

//set line height. This is the height of each lines, not rows.


//add table heading using standard cells
//set font to bold
$pdf->SetFont('Arial','B',12);
$pdf->SetFillColor(205,205,205);
$pdf->Cell(50,9,"CAPITULO",1,0,'C',true);
$pdf->Cell(80,9,"NOMBRE",1,0,'C',true);
$pdf->Cell(25,9,"NOTA",1,0,'C',true);


$pdf->Ln();
$pdf->SetLineHeight(7);
//reset font
$pdf->SetFont('Arial','',12);
//loop the data
foreach($data['certificado'] as $item){
	//write data using Row() method containing array of values.
	$pdf->Row(Array(
		utf8_decode($item['capitulo']),
		utf8_decode($item['tema']),
		$item['nota']		
	));
	
}
$pdf->Ln(10);
$pdf->SetFont('Arial','B',12);
$pdf->Cell(100,2, "Promedio Final: ".utf8_decode($data['alumno']['promedio']),0,0,'L');
$fecha = strftime("%d de %B del %Y");
$pdf->Ln(5);
$pdf->SetFont('Arial','',12);

$pdf->Cell(155,2, "Barranco, ".$fecha,0,0,'R');

//output the pdf
ob_start(); 
$pdf->Output('C:\REYES.PDF','I');
ob_end_flush();