<?php
//include pdf_mc_table.php, not fpdf17/fpdf.php
//call main fpdf file
require_once "Assets/fpdf/fpdf.php";

//create new class extending fpdf class
class PDF extends FPDF {
	// variable to store widths and aligns of cells, and line height
	var $widths;
	var $aligns;
	var $lineHeight;

	//Set the array of column widths
	function SetWidths($w){
		$this->widths=$w;
	}

	//Set the array of column alignments
	function SetAligns($a){
		$this->aligns=$a;
	}

	//Set line height
	function SetLineHeight($h){
		$this->lineHeight=$h;
	}

	//Calculate the height of the row
	function Row($data)
	{
		// number of line
		$nb=0;
		
		// loop each data to find out greatest line number in a row.
		for($i=0;$i<count($data);$i++){
			// NbLines will calculate how many lines needed to display text wrapped in specified width.
			// then max function will compare the result with current $nb. Returning the greatest one. And reassign the $nb.
			$nb=max($nb,$this->NbLines($this->widths[$i],$data[$i]));
		}
		
		//multiply number of line with line height. This will be the height of current row
		$h=$this->lineHeight * $nb;
		
		//Issue a page break first if needed
		$this->CheckPageBreak($h);
		
		//Draw the cells of current row
		for($i=0;$i<count($data);$i++)
		{
			// width of the current col
			$w=$this->widths[$i];
			
			// alignment of the current col. if unset, make it left.
			$a=isset($this->aligns[$i]) ? $this->aligns[$i] : 'L';
			
			//Save the current position
			$x=$this->GetX();
			$y=$this->GetY();
			
			//Draw the border
			$this->Rect($x,$y,$w,$h);
			
			//Print the text
			$this->MultiCell($w,5,$data[$i],0,$a);
			
			//Put the position to the right of the cell
			$this->SetXY($x+$w,$y);
		}
		//Go to the next line
		$this->Ln($h);
	}

	function CheckPageBreak($h)
	{
		//If the height h would cause an overflow, add a new page immediately
		if($this->GetY()+$h>$this->PageBreakTrigger)
			$this->AddPage($this->CurOrientation);
	}

	function NbLines($w,$txt)
	{
		//calculate the number of lines a MultiCell of width w will take
		$cw=&$this->CurrentFont['cw'];
		if($w==0)
			$w=$this->w-$this->rMargin-$this->x;
		$wmax=($w-2*$this->cMargin)*1000/$this->FontSize;
		$s=str_replace("\r",'',$txt);
		$nb=strlen($s);
		if($nb>0 and $s[$nb-1]=="\n")
			$nb--;
		$sep=-1;
		$i=0;
		$j=0;
		$l=0;
		$nl=1;
		while($i<$nb)
		{
			$c=$s[$i];
			if($c=="\n")
			{
				$i++;
				$sep=-1;
				$j=$i;
				$l=0;
				$nl++;
				continue;
			}
			if($c==' ')
				$sep=$i;
			$l+=$cw[$c];
			if($l>$wmax)
			{
				if($sep==-1)
				{
					if($i==$j)
						$i++;
				}
				else
					$i=$sep+1;
				$sep=-1;
				$j=$i;
				$l=0;
				$nl++;
			}
			else
				$i++;
		}
		return $nl;
	}

	function Header()
	{
		$this->SetMargins(20,15,20);
		$this->Image('Assets/img/logo.png',20,5,70,10);			
		$this->Ln(11);
		// Definimos la fuente y tamaño (180)
		$this->SetFont('Arial','B',10);
		$this->SetFillColor(205,205,205);
		$this->Ln(5);
		$this->Cell(10,9,"No",1,0,'C',true);
		$this->Cell(90,9,"APELLIDOS Y NOMBRES",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 1",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 2",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 3",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 4",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 5",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 6",1,0,'C',true);
		$this->Cell(20,9,"EXAMEN 7",1,0,'C',true);
		$this->Cell(20,9,"FINAL",1,0,'C',true);
		$this->Ln();
		$this->SetLineHeight(7);
		//reset font

	}

	function Footer()
	{
	$this->SetY(-15);
	$this->SetFont('Arial','B',8);
	$this->Cell(100,10,utf8_decode('Educación'),0,0,'L');
	$this->AliasNbPages();
	$this->Cell(160,10,$this->PageNo().'/{nb}',0,0,'R');

	}

}

//Crear Nuevo Objeto PDF
$pdf = new PDF('L');
setlocale(LC_ALL,"es_ES");
//add page, set font

$pdf->AddPage();
$pdf->Image('Assets/img/fondo_agua.jpg',100,50,100,100);	
$pdf->SetMargins(20,15,20);
$pdf->SetFont('Arial','U',12);
$pdf->text(80,24,utf8_decode("NOTAS FINALES DEL CURSO DE: COOPERATIVISMO ").$data['modulo']['cursomodulo']);
$pdf->SetFont('Arial','',10);
$pdf->SetFont('Arial','',10);
$pdf->SetWidths(Array(10,90,20,20,20,20,20,20,20,20));
$pdf->SetAligns(array('L','L','C','C','C','C','C','C','C','C'));
$numord=0;
foreach($data['matricula'] as $item){$numord++;
	//write data using Row() method containing array of values.
	$pdf->Row(Array(
		$numord,
		utf8_decode($item['alumno']),
		$item['nota1'],
		$item['nota2'],
		$item['nota3'],
		$item['nota4'],
		$item['nota5'],
		$item['nota6'],
		$item['nota7'],
		$item['promedio']
	));
}
//output the pdf
ob_start(); 
$pdf->Output('C:\REYES.PDF','I');
ob_end_flush();